@@ -1,6 +1,6 @@
-//$Id: list-prop.cc,v 1.19 2002/11/10 16:47:02 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.21 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -33,7 +33,6 @@
 
 #include <gtk--/notebook.h>
 
-#include "widget-prop.h"
 #include "auto-resizeable-prop.h"
 
 #include "property-ops-widget.h"
@@ -41,7 +40,8 @@
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
-ListProperties::ListProperties (List *res)
+ListProperties::ListProperties (List *res):
+    WidgetProperties (res)
 {
     using namespace SigC;
     using WidgetOps::PropChangeOpFactory;
@@ -54,7 +54,7 @@ ListProperties::ListProperties (List *res)
     Gtk::Widget *control;
 
     /* Resource ID */
-    WidgetProperties::add_general_controls (res, *proptable);
+    add_general_controls (*proptable);
 
     /* Font */
     control = new GUI::PropertyEditors::FontCombo (
@@ -80,7 +80,7 @@ ListProperties::ListProperties (List *res)
     proptable->add_separator ();
 
     /* Position */
-    WidgetProperties::add_position_controls (res, *proptable);
+    add_position_controls (*proptable);
 
     /* Width */
     AutoWidthProperties::add_controls (res, *proptable);
