@@ -1,4 +1,4 @@
-//$Id: pushbutton-prop.cc,v 1.18 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-prop.cc,v 1.20 2004/01/18 10:55:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,7 @@
 
 #include "auto-resizeable-prop.h"
 #include "textual-prop.h"
+#include "graphical-prop.h"
 
 #include "widgets/entry.h"
 #include "widgets/num-entry.h"
@@ -49,6 +50,9 @@ PushButtonProperties::PushButtonProperties (PushButton *res):
     /* Label */
     TextualProperties::add_controls (res, *proptable);
 
+    /* Bitmaps */
+    GraphicalProperties::add_controls (res, *proptable);
+    
     /* Usable */
     control = new GUI::PropertyEditors::ToggleButton (
 	res->usable,
