@@ -1,4 +1,4 @@
-//$Id: pushbutton.cc,v 1.27 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.30 2004/01/18 10:55:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,6 +31,7 @@ PushButton::PushButton (Resources::Form   *owner,
     AutoWidth (changed),
     AutoHeight (changed),
     Textual (changed, id),
+    Graphical (changed, owner->get_manager ()),
     
     usable (changed, true),
     group (changed)
@@ -44,5 +45,5 @@ int PushButton::get_auto_width () const
 
 int PushButton::get_auto_height () const
 {
-    return get_font_height (font);
+    return get_font_height (font) + 1;
 }
