@@ -1,4 +1,4 @@
-//$Id: pushbutton.h,v 1.20 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.h,v 1.22 2004/01/18 10:55:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include "widget.h"
 #include "auto-resizeable.h"
 #include "textual.h"
+#include "graphical.h"
 
 namespace Guikachu
 {
@@ -30,7 +31,8 @@ namespace Guikachu
 	class PushButton: public Widget,
 			  public AutoWidth,
 			  public AutoHeight,
-			  public Textual
+			  public Textual,
+                          public Graphical
 	{
 	public:
 	    PushButton (Resources::Form *owner, const std::string &id, serial_t serial);
@@ -40,7 +42,7 @@ namespace Guikachu
 	    
 	    Property<bool>   usable;
 	    Property<int>    group;
-
+	    
 	protected:
 	    int get_auto_width  () const;
 	    int get_auto_height () const;
