@@ -1,4 +1,4 @@
-//$Id: table-canvas.cc,v 1.16 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.cc,v 1.18 2003/12/20 15:50:10 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,7 @@
 #include "table-canvas.h"
 
 #include "form-editor.h"
+#include "form-editor-canvas.h"
 #include "resizeable-ops.h"
 
 #include <gnome--/canvas-polygon.h>
@@ -29,6 +30,7 @@ using namespace Guikachu::GUI::FormEditor;
 namespace
 {
 void draw_table_line (Gnome::CanvasGroup &group,
+                      const Gdk_Color    &color,
 		      int x1, int y1,
 		      int x2, int y2)
 {
@@ -45,7 +47,7 @@ void draw_table_line (Gnome::CanvasGroup &group,
     line_points.push_back (Gnome::Art::Point (x2, y2));
     
     *(new Gnome::CanvasLine (group, line_points))
-	<< fill_color (get_foreground_color (true))
+	<< fill_color (color)
 	<< fill_stipple (stipple);
 }
     
@@ -74,12 +76,13 @@ void TableCanvasItem::update ()
     /* Column separators */
     int width  = 0;
     int height = widget->num_rows * 11;
-
+    Gdk_Color color = get_foreground_color (true);
+    
     int x1 = widget->x;
     int y1 = widget->y;
     int y2 = y1 + std::min (height, widget->get_height ());
-
-    draw_table_line (*group, x1, y1, x1, y2);
+    
+    draw_table_line (*group, color, x1, y1, x1, y2);
 
     int num_columns = widget->num_columns;
     for (int i = 0; i < num_columns; i++)
@@ -88,13 +91,13 @@ void TableCanvasItem::update ()
 	int line_x = x1 + width;
 
 	if (width <= widget->get_width ())
-	    draw_table_line (*group, line_x, y1, line_x, y2);
+	    draw_table_line (*group, color, line_x, y1, line_x, y2);
     }
     
     int x2 = x1 + std::min (width, widget->get_width ());
     
     /* Row separators */
-    draw_table_line (*group, x1, y1, x2, y1);
+    draw_table_line (*group, color, x1, y1, x2, y1);
     const int row_step = 11;
     int row_y = 0;
     for (int i = 0; i < widget->num_rows; i++)
@@ -103,7 +106,7 @@ void TableCanvasItem::update ()
 	if (row_y > widget->get_height ())
 	    break;
 	
-	draw_table_line (*group, x1, y1 + row_y, x2, y1 + row_y);
+	draw_table_line (*group, color, x1, y1 + row_y, x2, y1 + row_y);
     }
     
     /* A Polygon is used instead of a Rectangle to get mouse events
