@@ -1,4 +1,4 @@
-//$Id: io.h,v 1.3 2002/08/15 23:10:03 cactus Exp $ -*- c++ -*-
+//$Id: io.h,v 1.4 2004/01/21 19:50:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,6 +30,8 @@ namespace Guikachu
 	typedef GnomeVFSResult IOResult;
 
 	std::string create_canonical_uri (const std::string &filename);
+	IOResult load_uri (const std::string &uri, char *&data, GnomeVFSFileSize &len);
+	IOResult save_uri (const std::string &uri, const char *data, GnomeVFSFileSize len);
 	
 	class Loader
 	{
