@@ -1,4 +1,4 @@
-//$Id: widget-pushbutton.cc,v 1.1 2002/08/01 18:06:07 cactus Exp $ -*- c++ -*-
+//$Id: widget-pushbutton.cc,v 1.2 2004/01/17 22:12:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,10 +33,12 @@ PushButtonIOAdaptor::PushButtonIOAdaptor (Widgets::PushButton *widget_):
 void PushButtonIOAdaptor::load (const StorageNode &node)
 {
     StorageProcessor processor;
-    processor.add_handler ("pos",    new SizePosHandler (widget));
-    processor.add_handler ("text",   new TextHandler (widget));
-    processor.add_handler ("usable", new StorageNodeHandlers::Flag (widget->usable));
-    processor.add_handler ("group",  new StorageNodeHandlers::IntProp ("id", widget->group));
+    processor.add_handler ("pos",            new SizePosHandler (widget));
+    processor.add_handler ("text",           new TextHandler (widget));
+    processor.add_handler ("image",          new StorageNodeHandlers::StringProp ("id", widget->bitmap_id));
+    processor.add_handler ("selected_image", new StorageNodeHandlers::StringProp ("id", widget->selected_bitmap_id));
+    processor.add_handler ("usable",         new StorageNodeHandlers::Flag (widget->usable));
+    processor.add_handler ("group",          new StorageNodeHandlers::IntProp ("id", widget->group));
     
     processor.run (node);
 }
@@ -52,6 +54,19 @@ void PushButtonIOAdaptor::save (StorageNode &node)
     /* Label and font */
     save_widget_text (widget, node);
     
+    /* Pictures */
+    if (widget->bitmap_id != "")
+    {
+	StorageNode bitmap_node = node.add_node ("image");
+	bitmap_node.set_prop ("id", widget->bitmap_id);
+    }
+
+    if (widget->selected_bitmap_id != "")
+    {
+	StorageNode bitmap_node = node.add_node ("selected_image");
+	bitmap_node.set_prop ("id", widget->bitmap_id);
+    }	
+    
     /* Group ID */
     node.add_node ("group").set_prop ("id", widget->group);
 }
