@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.29 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.30 2003/12/15 17:35:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,12 +33,11 @@
 #include <sigc++/retbind.h>
 
 using namespace Guikachu;
-using std::string;
 
-static string time_ago_string (time_t ago)
+static std::string time_ago_string (time_t ago)
 {
-    string  ret_val;
-    gchar  *buf = 0;
+    std::string  ret_val;
+    gchar       *buf = 0;
     
     int minutes = ago / 60;
     int hours = minutes / 60;
@@ -92,7 +91,7 @@ bool GUI::MainWin::check_save ()
     g_free (filename_message);
 
     Gnome::Dialog *dialog = new Gnome::MessageBox (
-	message, GNOME_MESSAGE_BOX_WARNING, std::vector<string>());
+	message, GNOME_MESSAGE_BOX_WARNING, std::vector<std::string>());
 
     static const int save_btn = 2;
     static const int discard_btn = 0;
@@ -134,7 +133,7 @@ void GUI::MainWin::new_cb ()
     Guikachu::Main::instance ()->new_doc ();
 }
 
-void GUI::MainWin::set_filename (const string &filename_)
+void GUI::MainWin::set_filename (const std::string &filename_)
 {
     filename = filename_;
     update_title ();
@@ -250,7 +249,7 @@ void GUI::MainWin::filesel_save_cb (Gtk::FileSelection *fs)
 
 void GUI::MainWin::filesel_open_cb (Gtk::FileSelection *fs)
 {
-    string new_filename = fs->get_filename ();
+    std::string new_filename = fs->get_filename ();
     filesel_close_cb (fs);
 
     open (new_filename);
@@ -258,7 +257,7 @@ void GUI::MainWin::filesel_open_cb (Gtk::FileSelection *fs)
 
 void GUI::MainWin::filesel_export_cb (Gtk::FileSelection *fs)
 {
-    string filename = fs->get_filename ();
+    std::string filename = fs->get_filename ();
     filesel_close_cb (fs);
 
     IO::Saver    *rcp_saver = new IO::RCPSaver;
