@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.50 2003/12/15 17:35:37 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.53 2004/01/30 21:36:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,9 +18,6 @@
 
 #include "resource-manager.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
-
 #include "ui.h"
 #include "resource-util.h"
 
@@ -31,44 +28,10 @@
 #include "stringlist-res.h"
 #include "blob-res.h"
 #include "bitmap-res.h"
-
-#include <fstream>
+#include "bitmapfamily-res.h"
 
 using namespace Guikachu;
 
-#define ASCII_TOUPPER(c)  (((c) >= 'a' && (c) <= 'z') ? (c) - 32 : (c))
-
-int NoCase::compare (const std::string &x, const std::string &y) const
-{
-    // We can't use strncmp() as that would be locale-dependant
-    std::string::const_iterator p = x.begin ();
-    std::string::const_iterator q = y.begin ();
-
-    while (p != x.end () && q != y.end () &&
-	   ASCII_TOUPPER (*p) == ASCII_TOUPPER (*q))
-    {
-	p++;
-	q++;
-    }
-
-    // Return value:  0 if x == y
-    //               +1 if x > y
-    //               -1 if x < y
-    if (p == x.end () && q == y.end ()) return 0;
-    if (p == x.end ()) return -1;
-    if (q == y.end ()) return 1;
-
-    return ASCII_TOUPPER (*p) < ASCII_TOUPPER (*q) ? -1 : 1;
-}
-
-bool NoCase::operator () (const std::string &x, const std::string &y) const
-{
-    // Return value: true  if x <  y
-    //               false if x >= y
-    return (compare (x, y) < 0);
-}
-
-
 ResourceManager::ResourceManager ():
     app (this)
 {
@@ -88,60 +51,6 @@ ResourceManager::~ResourceManager ()
 	delete i->second;
 }
 
-std::string ResourceManager::create_id (const std::string &prefix)
-{
-    unsigned int num = 0;
-    std::string ret_val;
-    gchar *curr_name;
-    const char *prefix_str = prefix.c_str ();
-    
-    for (num = 1; num != 0; num++)
-    {
-	curr_name = g_strdup_printf ("%s%d", prefix_str, num);
-
-	if (id_set.find (curr_name) == id_set.end ())
-	{
-	    ret_val = curr_name;
-	    g_free (curr_name);
-	    break;
-	} else {
-	    g_free (curr_name);
-	}
-    }
-
-    if (!num)
-	return "";
-
-    return ret_val;
-}
-
-bool ResourceManager::register_id (const std::string &id)
-{
-    if (id_set.find (id) != id_set.end ())
-	return false;
-
-    id_set.insert (id);
-    return true;
-}
-
-void ResourceManager::unregister_id (const std::string &id)
-{
-    id_set.erase (id);
-}
-
-std::string ResourceManager::validate_id (std::string id)
-{
-    std::string allowed_characters =
-	"abcdefghijklmnopqrstuvwxyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789";
-    
-    for (std::string::iterator i = id.begin ();
-	 i != id.end (); i++)
-	if (allowed_characters.find (*i) == std::string::npos)
-	    *i = '_';
-
-    return id;
-}
-
 namespace
 {
     bool compare_serial (const ResourceManager::resource_map_t::value_type &a,
@@ -206,6 +115,9 @@ Resource* ResourceManager::create_resource (Resources::Type type,
     case Resources::RESOURCE_BITMAP:
         res = new Resources::Bitmap (this, id, serial);
         break;
+    case Resources::RESOURCE_BITMAPFAMILY:
+        res = new Resources::BitmapFamily (this, id, serial);
+        break;
     case Resources::RESOURCE_FORM:
 	form = new Resources::Form (this, id, serial);
 	form->widget_changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
@@ -226,51 +138,6 @@ Resource* ResourceManager::create_resource (Resources::Type type,
     return res;
 }
 
-bool ResourceManager::rename_resource (const std::string &old_id,
-				       const std::string &new_id)
-{
-    // No-ops: old_id == new_id
-    if (old_id == new_id)
-	return true;
-
-    // No-ops: new_id and old_id differ only in case
-    if (NoCase ().compare (old_id, new_id) == 0)
-	return true;
-
-    // Error: empty id
-    if (new_id == "")
-	return false;
-
-    // Error: old_id does not exist
-    if (id_set.find (old_id) == id_set.end ())
-	return false;
-
-    if (id_set.find (new_id) != id_set.end ())
-    {
-	char *error_msg = g_strdup_printf (_("Non-unique identifier `%s'"), new_id.c_str ());
-	UI::show_error (error_msg);
-	g_free (error_msg);
-
-	return false;
-    }
-    
-    id_set.erase (old_id);
-    id_set.insert (new_id);
-
-#if 0
-    resource_map_t::iterator old_entry = resource_map.find (old_id);
-    
-    if (old_entry != resource_map.end ())
-    {
-	Resource *res = old_entry->second;
-	resource_map.erase (old_entry);
-	resource_map.insert (std::make_pair (new_id, res));
-    }
-#endif
-
-    return true;
-}
-
 void ResourceManager::remove_resource (Resource* resource)
 {
     resource_removed.emit (resource);
@@ -296,27 +163,13 @@ std::set<Resource*> ResourceManager::get_resources () const
     return ret;
 }
 
-namespace {
-    struct resource_finder
-    {
-	std::string search_id;
-
-	bool operator () (const ResourceManager::resource_map_t::value_type &i) const
-	    {
-		return NoCase ().compare (i.second->id, search_id) == 0;
-	    }
-
-	resource_finder (const std::string &search_id_):
-	    search_id (search_id_)
-	    {}
-    };
-}
-
 Resource* ResourceManager::get_resource (const std::string &id) const
 {
-    resource_map_t::const_iterator found =
-	std::find_if (resource_map.begin (), resource_map.end (), resource_finder (id));
-
+    resource_map_t::const_iterator found;
+    for (found = resource_map.begin ();
+         found != resource_map.end () && NoCase ().compare (found->second->id, id);
+         ++found);
+    
     if (found == resource_map.end ())
 	return 0;
     else
