@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.29 2003/06/30 14:07:56 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.30 2004/01/30 01:08:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,39 +24,27 @@ namespace Guikachu
     class ResourceManager;
 }
 
+#include "id-manager.h"
+
 #include "resource.h"
 #include "app-res.h"
 #include "target.h"
 
 #include "undo.h"
 
-#include <map>
 #include <set>
 #include <sigc++/signal_system.h>
 #include <time.h>
 
 namespace Guikachu
 {
-    class NoCase
+    class ResourceManager: public IDManager, public SigC::Object
     {
     public:
-	int  compare     (const std::string &x, const std::string &y) const;
-	bool operator () (const std::string &x, const std::string &y) const;
-    };
-
-    // Forward declarations
-    class Target;
-    
-    class ResourceManager: public SigC::Object
-    {
-    public:
-//	typedef std::map<std::string, Resource*, NoCase> resource_map_t;
 	typedef std::map<serial_t, Resource*> resource_map_t;
-	typedef std::set<std::string, NoCase> id_set_t;
 
     private:
 	resource_map_t         resource_map;
-	id_set_t               id_set;
 	Resources::Application app;
 	Target                 target;
 
@@ -74,14 +62,6 @@ namespace Guikachu
 				   bool            try_alternate_names = false,
 				   serial_t        serial = -1);
 	void remove_resource (Resource *resource);
-	bool rename_resource (const std::string &old_id,
-			      const std::string &new_id);
-
-	bool register_id   (const std::string &id);
-	void unregister_id (const std::string &id);
-
-	std::string create_id   (const std::string &prefix);
-	std::string validate_id (std::string id);
 
 	std::set<Resource*>     get_resources   () const;
 	Resource*               get_resource    (const std::string &id) const;
